psudoSC: Calculate Psudo-single-cell Count Data

Description Usage Arguments Value

View source: R/projectLSI.R

Description

Calculate the psudo-single-cell RNA-seq data by down-sampling bulk RNA-seq counts.

Usage

1
psudoSC(bulk.data, n = 100, depth = 3000)

Arguments

bulk.data

the bulk RNA-seq counts matrix, genes in row and samples in column.

n

how many times to down-sample per bulk sample, default 100

depth

how many counts down-sample to, default 3000

Value

a sparse matrix of down-sampled count matrix with genes in row and n*sample psudo-cells in column


sajuukLyu/projectLSI documentation built on Jan. 18, 2022, 12:27 a.m.