Description Usage Arguments Value
Calculate the psudo-single-cell RNA-seq data by down-sampling bulk RNA-seq counts.
1 |
bulk.data |
the bulk RNA-seq counts matrix, genes in row and samples in column. |
n |
how many times to down-sample per bulk sample, default 100 |
depth |
how many counts down-sample to, default 3000 |
a sparse matrix of down-sampled count matrix with genes in row and n*sample psudo-cells in column
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.